@@ -47,6 +47,45 @@
 
 namespace folly {
 
+/// SplitOptions
+///
+/// Options for controlling split() behavior. This class uses a builder pattern
+/// to allow for easy configuration and method chaining.
+class SplitOptions {
+ public:
+  struct Defaults {
+    /// preallocate
+    ///
+    /// If true, split will count the expected number of tokens first
+    /// and pre-allocate container capacity using grow_capacity_by.
+    /// This can improve performance when splitting large strings with
+    /// many tokens, but may add overhead for small strings.
+    static constexpr bool preallocate = false;
+
+    /// ignoreEmpty
+    ///
+    /// If true, adjacent delimiters are treated as one single separator
+    /// (ignoring empty tokens), otherwise empty tokens are generated.
+    static constexpr bool ignore_empty = false;
+  };
+
+  constexpr bool preallocate() const { return preallocate_; }
+  constexpr SplitOptions& preallocate(bool enable) {
+    preallocate_ = enable;
+    return *this;
+  }
+
+  constexpr bool ignore_empty() const { return ignore_empty_; }
+  constexpr SplitOptions& ignore_empty(bool enable) {
+    ignore_empty_ = enable;
+    return *this;
+  }
+
+ private:
+  bool preallocate_ = Defaults::preallocate;
+  bool ignore_empty_ = Defaults::ignore_empty;
+};
+
 /**
  * @overloadbrief C-escape a string.
  *
@@ -348,6 +387,10 @@ enum PrettyType {
   PRETTY_UNITS_BINARY_IEC,
 
   PRETTY_SI,
+
+  PRETTY_BITS_METRIC,
+  PRETTY_BITS = PRETTY_BITS_METRIC,
+
   PRETTY_NUM_TYPES,
 };
 
@@ -372,6 +415,9 @@ enum PrettyType {
  *     PRETTY_UNITS_BINARY_IEC - Ki, Mi, Gi, etc
  *     PRETTY_SI           - full SI metric prefixes from yocto to Yotta
  *                           http://en.wikipedia.org/wiki/Metric_prefix
+ *     PRETTY_BITS_METRIC  - kb, Mb, Gb, etc (goes up by 10^3 = 1000 each time)
+ *                           Useful for network bandwidth (e.g., 1 Gbps)
+ *     PRETTY_BITS         - alias for PRETTY_BITS_METRIC
  *
  */
 std::string prettyPrint(double val, PrettyType, bool addSpace = true);
@@ -526,6 +572,20 @@ split(
     OutputType& out,
     const bool ignoreEmpty = false);
 
+/**
+ * Split a string into a list of tokens by delimiter with options.
+ *
+ * Same as split() above but with additional options to control behavior.
+ * The SplitOptions allow enabling preallocation which can improve performance
+ * when splitting large strings with many expected tokens.
+ */
+template <class Delim, class String, class OutputType>
+std::enable_if_t<detail::IsSplitSupportedContainer<OutputType>::value> split(
+    const Delim& delimiter,
+    const String& input,
+    OutputType& out,
+    const SplitOptions& options);
+
 /**
  * split, to an output iterator
  */
@@ -800,9 +860,25 @@ inline bool hasSpaceOrCntrlSymbols(folly::StringPiece s) {
 }
 
 struct format_string_for_each_named_arg_fn {
+  struct options {
+    bool numeric_args_as_named = false;
+
+    options& set_numeric_args_as_named(bool value) noexcept {
+      numeric_args_as_named = value;
+      return *this;
+    }
+  };
+
   template <typename C, typename CT, typename Fn>
   constexpr void operator()(std::basic_string_view<C, CT> str, Fn fn) const
       noexcept(noexcept(fn(str))) {
+    return operator()(options{}, str, std::ref(fn));
+  }
+
+  template <typename C, typename CT, typename Fn>
+  constexpr void operator()(
+      options const& opts, std::basic_string_view<C, CT> str, Fn fn) const
+      noexcept(noexcept(fn(str))) {
     using view = std::basic_string_view<C, CT>;
     while (true) {
       auto const pos = str.find('{');
@@ -820,7 +896,7 @@ struct format_string_for_each_named_arg_fn {
       }
       auto const arg = str.substr(beg, end - beg);
       auto const c = arg.empty() ? 0 : arg[0];
-      if (c && !(c >= '0' && c <= '9')) {
+      if (c && (opts.numeric_args_as_named || !(c >= '0' && c <= '9'))) {
         fn(arg);
       }
       str = str.substr(end);
@@ -831,6 +907,9 @@ struct format_string_for_each_named_arg_fn {
 inline constexpr format_string_for_each_named_arg_fn
     format_string_for_each_named_arg{};
 
+using format_string_for_each_named_arg_options =
+    format_string_for_each_named_arg_fn::options;
+
 } // namespace folly
 
 #include <folly/String-inl.h>
