@@ -37,7 +37,14 @@ class IoUringZeroCopyBufferPoolTestHelper {
   uint32_t getRingUsedCount() { return pool.getRingUsedCount(); }
   uint32_t getRingFreeCount() { return pool.getRingFreeCount(); }
   size_t getPendingBuffersSize() { return pool.getPendingBuffersSize(); }
+  uint32_t getFlushThreshold() { return pool.getFlushThreshold(); }
+  uint64_t getAndResetFlushFailures() {
+    return pool.getAndResetFlushFailures();
+  }
 
+  void consumeRefillRingEntries(uint32_t numEntries) {
+    *getHead() += numEntries;
+  }
   IoUringZeroCopyBufferPool& pool;
 };
 } // namespace folly
@@ -120,7 +127,7 @@ TEST(IoUringZeroCopyBufferPoolTest, RefillTest) {
   EXPECT_EQ(helper.getRingFreeCount(), 0);
   EXPECT_EQ(helper.getPendingBuffersSize(), 1);
 
-  *helper.getHead() += 2;
+  helper.consumeRefillRingEntries(2);
   EXPECT_EQ(helper.getRingUsedCount(), 0);
   EXPECT_EQ(helper.getRingFreeCount(), 2);
   EXPECT_EQ(helper.getPendingBuffersSize(), 1);
@@ -133,6 +140,80 @@ TEST(IoUringZeroCopyBufferPoolTest, RefillTest) {
   EXPECT_EQ(helper.getPendingBuffersSize(), 0);
 }
 
+TEST(IoUringZeroCopyBufferPoolTest, RefillWithFlush) {
+  IoUringZeroCopyBufferPool::Params params = {
+      .ring = nullptr,
+      .numPages = 200,
+      .pageSize = 4096,
+      .rqEntries = 8,
+      .ifindex = 0,
+      .queueId = 0,
+  };
+  auto pool = IoUringZeroCopyBufferPoolTestHelper::create(params);
+  IoUringZeroCopyBufferPoolTestHelper helper(*pool);
+
+  EXPECT_EQ(helper.getRingUsedCount(), 0);
+  EXPECT_EQ(helper.getRingFreeCount(), 8);
+  EXPECT_EQ(helper.getPendingBuffersSize(), 0);
+
+  io_uring_cqe cqe{};
+  io_uring_zcrx_cqe zcqe{};
+  cqe.res = 2048;
+  zcqe.off = 0;
+
+  for (int i = 0; i < 150; i++) {
+    auto buf = pool->getIoBuf(&cqe, &zcqe);
+    zcqe.off += 4096;
+  }
+
+  EXPECT_EQ(helper.getRingUsedCount(), 8);
+  EXPECT_EQ(helper.getRingFreeCount(), 0);
+  EXPECT_EQ(helper.getPendingBuffersSize(), 142);
+
+  helper.consumeRefillRingEntries(8);
+
+  EXPECT_EQ(helper.getRingUsedCount(), 0);
+  EXPECT_EQ(helper.getRingFreeCount(), 8);
+  EXPECT_EQ(helper.getPendingBuffersSize(), 142);
+
+  {
+    auto buf = pool->getIoBuf(&cqe, &zcqe);
+    zcqe.off += 4096;
+  }
+
+  EXPECT_EQ(helper.getRingUsedCount(), 8);
+  EXPECT_EQ(helper.getRingFreeCount(), 0);
+  EXPECT_EQ(helper.getPendingBuffersSize(), 135);
+  helper.consumeRefillRingEntries(8);
+
+  // Simulate kernel consuming 8 entries from the refill ring, then get 10 more
+  // buffers. This triggers automatic flush when pending queue reaches 128.
+  // The flush allows the kernel to consume more entries, reducing pending size.
+  for (int i = 0; i < 10; i++) {
+    auto buf = pool->getIoBuf(&cqe, &zcqe);
+    zcqe.off += 4096;
+  }
+
+  // After getting 10 buffers: 8 went to the now-empty ring, and pending queue
+  // had 135, so we'd have 135 - 8 + 10 = 137 pending. In test mode (no real
+  // kernel), flush is a no-op so the count is deterministic.
+  EXPECT_EQ(helper.getRingUsedCount(), 8);
+  EXPECT_EQ(helper.getPendingBuffersSize(), 137);
+
+  helper.consumeRefillRingEntries(8);
+
+  while (helper.getPendingBuffersSize() > 0) {
+    auto buf = pool->getIoBuf(&cqe, &zcqe);
+    zcqe.off += 4096;
+    if (helper.getRingUsedCount() == 8) {
+      helper.consumeRefillRingEntries(8);
+    }
+  }
+  EXPECT_EQ(helper.getPendingBuffersSize(), 0);
+
+  pool.reset();
+}
+
 TEST(IoUringZeroCopyBufferPoolTest, RefillMoreThanCapacity) {
   IoUringZeroCopyBufferPool::Params params = {
       .ring = nullptr,
@@ -161,7 +242,7 @@ TEST(IoUringZeroCopyBufferPoolTest, RefillMoreThanCapacity) {
   EXPECT_EQ(helper.getRingFreeCount(), 0);
   EXPECT_EQ(helper.getPendingBuffersSize(), 6);
 
-  *helper.getHead() += 2;
+  helper.consumeRefillRingEntries(2);
   zcqe.off = 0;
   for (int i = 0; i < 2; i++) {
     auto buf = pool->getIoBuf(&cqe, &zcqe);
