@@ -978,8 +978,9 @@ void cohort_safe_list_children_test() {
   DCHECK_EQ(sum, 4000);
 }
 
-void fork_test() {
 #ifndef _WIN32
+
+void fork_test() {
   folly::enable_hazptr_thread_pool_executor();
   auto trigger_reclamation = [] {
     hazptr_obj_cohort b;
@@ -1010,9 +1011,10 @@ void fork_test() {
   } else {
     PLOG(FATAL) << "Failed to fork()";
   }
-#endif
 }
 
+#endif
+
 template <template <typename> class Atom = std::atomic>
 void lifo_test() {
   for (int i = 0; i < FLAGS_num_reps; ++i) {
@@ -1092,7 +1094,7 @@ class HazptrPreInitTest : public testing::Test {
  private:
   // pre-init to avoid deadlock when using DeterministicAtomic
   hazptr_domain<DeterministicAtomic>& defaultDomainHelper_{
-      folly::hazptr_default_domain_helper<DeterministicAtomic>::get()};
+      folly::default_hazptr_domain<DeterministicAtomic>()};
 };
 
 // Tests
@@ -1307,10 +1309,14 @@ TEST(HazptrTest, cohortSafeListChildren) {
   cohort_safe_list_children_test();
 }
 
+#ifndef _WIN32
+
 TEST(HazptrTest, fork) {
   fork_test();
 }
 
+#endif
+
 TEST(HazptrTest, lifo) {
   lifo_test();
 }
