@@ -44,7 +44,7 @@ DEFINE_int32(work, 100, "Number of work cycles");
 DEFINE_int32(unlocked_work, 1000, "Number of unlocked work cycles");
 DEFINE_int32(
     threads,
-    folly::hardware_concurrency(),
+    folly::available_concurrency(),
     "Number of threads for fairness test");
 DEFINE_bool(run_fairness, true, "Run fairness benchmarks");
 
@@ -231,7 +231,7 @@ template <typename Lock, typename Data = std::uint64_t>
 static void runContended(
     size_t numOps, size_t numThreads, size_t work = FLAGS_work) {
   folly::BenchmarkSuspender braces;
-  size_t totalthreads = folly::hardware_concurrency();
+  size_t totalthreads = folly::available_concurrency();
   if (totalthreads < numThreads) {
     totalthreads = numThreads;
   }
@@ -281,7 +281,7 @@ static void runContended(
 
 template <typename Lock>
 static void runFairness(std::size_t numThreads) {
-  size_t totalthreads = folly::hardware_concurrency();
+  size_t totalthreads = folly::available_concurrency();
   if (totalthreads < numThreads) {
     totalthreads = numThreads;
   }
